@@ -29,6 +29,16 @@ class HelperFunctions:
     def getResourcePath(cls):
         path = os.path.dirname(__file__) + "/resources"
         return path
+    
+    @classmethod
+    def absoluteFilePaths(cls,directory):
+        """
+        Get all file paths in the given directory.
+        """
+        #https://stackoverflow.com/questions/9816816/get-absolute-paths-of-all-files-in-a-directory
+        for dirpath, _, filenames in os.walk(directory):
+            for f in filenames:
+                yield os.path.abspath(os.path.join(dirpath, f))
 
     @classmethod
     def getSMW_WikiUser(cls,wikiId="or",save=False):
@@ -41,6 +51,8 @@ class HelperFunctions:
             wikiDict=None
             if wikiId=="or":
                 wikiDict={"wikiId": wikiId,"email":"noreply@nouser.com","url":"https://www.openresearch.org","scriptPath":"/mediawiki/","version":"MediaWiki 1.31.1"}
+            if wikiId=="orclone":
+                wikiDict={"wikiId": wikiId,"email":"noreply@nouser.com","url":"https://confident.dbis.rwth-aachen.de","scriptPath":"/or/","version":"MediaWiki 1.35.1"}
             if wikiId=="cr":
                 wikiDict={"wikiId": wikiId,"email":"noreply@nouser.com","url":"https://cr.bitplan.com","scriptPath":"/","version":"MediaWiki 1.33.4"}
                 
